@@ -1,11 +1,12 @@
-import os
 from yafowil.base import factory
+from yafowil.utils import entry_point
+import os
 
 
 resourcedir = os.path.join(os.path.dirname(__file__), 'resources')
 js = [{
     'group': 'yafowil.widget.slider.dependencies',
-    'resource': 'jquery-ui-1.8.18.slider.min.js',
+    'resource': 'jquery.ui.slider.min.js',
     'order': 20,
 }, {
     'group': 'yafowil.widget.slider.common',
@@ -14,7 +15,7 @@ js = [{
 }]
 default_css = [{
     'group': 'yafowil.widget.slider.dependencies',
-    'resource': 'jquery-ui-1.8.18.slider.css',
+    'resource': 'jquery.ui.slider.css',
     'order': 20,
 }, {
     'group': 'yafowil.widget.slider.common',
@@ -23,7 +24,16 @@ default_css = [{
 }]
 bootstrap_css = [{
     'group': 'yafowil.widget.slider.dependencies',
-    'resource': 'jquery-ui-1.8.16.slider.bootstrap.css',
+    'resource': 'jquery.ui.slider.bootstrap.css',
+    'order': 20,
+}, {
+    'group': 'yafowil.widget.slider.common',
+    'resource': 'widget.css',
+    'order': 21,
+}]
+plone5_css = [{
+    'group': 'yafowil.widget.slider.dependencies',
+    'resource': 'jquery.ui.slider.plone5.css',
     'order': 20,
 }, {
     'group': 'yafowil.widget.slider.common',
@@ -32,9 +42,12 @@ bootstrap_css = [{
 }]
 
 
+@entry_point(order=10)
 def register():
-    import widget
+    from yafowil.widget.slider import widget
     factory.register_theme('default', 'yafowil.widget.slider',
                            resourcedir, js=js, css=default_css)
     factory.register_theme('bootstrap', 'yafowil.widget.slider',
-                           resourcedir, js=js, css=bootstrap_css)
\ No newline at end of file
+                           resourcedir, js=js, css=bootstrap_css)
+    factory.register_theme('plone5', 'yafowil.widget.slider',
+                           resourcedir, js=js, css=plone5_css)
